@@ -17,7 +17,7 @@ LSX_ and lsx_ symbols should not be used by libSoX-based applications.
 */
 
 #ifndef SOX_H
-#define SOX_H /**< Client API: This macro is defined if sox.h has been included. */
+#define SOX_H /**< Client API: This macro is defined if sox_ng.h has been included. */
 
 #include <limits.h>
 #include <stdarg.h>
@@ -44,7 +44,7 @@ Plugins API:
 Attribute required on all functions exported by libSoX and on all function
 pointer types used by the libSoX API.
 */
-#if defined(__GNUC__) && defined(__i386)
+#ifdef __GNUC__
 #define LSX_API  __attribute__ ((cdecl)) /* libSoX function */
 #elif _MSC_VER
 #define LSX_API  __cdecl /* libSoX function */
@@ -659,11 +659,10 @@ Compute a 32-bit integer API version from three 8-bit parts.
 
 /**
 Client API:
-The API version of the sox.h file. It is not meant to follow the version
-number of SoX but it has historically. Please do not count on
-SOX_LIB_VERSION_CODE staying in sync with the libSoX version.
+The API version of the sox_ng.h file. It follows the version number of SoX
+because that's what sox --version reports.
 */
-#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 4, 2)
+#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 4, 4)
 
 /**
 Client API:
@@ -1025,8 +1024,8 @@ and increment a counter if clipping occurs.
 @returns Clipped value.
 */
 #define SOX_INTEGER_CLIP_COUNT(bits,i,clips) ( \
-  (i) >(1 << ((bits)-1))- 1? ++(clips),(1 << ((bits)-1))- 1 : \
-  (i) <-1 << ((bits)-1)    ? ++(clips),-1 << ((bits)-1) : (i))
+  (i) >(int)((unsigned)1 << ((bits)-1))- 1 ? ++(clips),((unsigned)1 << ((bits)-1))- 1 : \
+  (i) <(int)((unsigned)-1 << ((bits)-1))   ? ++(clips),(unsigned)-1 << ((bits)-1) : (i))
 
 /**
 Client API:
@@ -2450,7 +2449,7 @@ Finds the file extension for a filename.
 @returns the file extension, not including the '.', or null if filename does
 not have an extension.
 */
-LSX_RETURN_VALID_Z LSX_RETURN_PURE
+LSX_RETURN_OPT LSX_RETURN_PURE
 char const *
 LSX_API
 lsx_find_file_extension(
